Views
=====

Social Connections
------------------

*URL name*:
  ``socialaccount_connections``

The ``allauth.socialaccount.views.ConnectionsView`` view over at
``/accounts/social/connections/`` (URL name ``socialaccount_connections``) allows
users to manage the social accounts tied to their local account.
